#include "pieDialog.h"
#include "textDialog.h"
#include "colorBox.h"
#include "patternBox.h"

#include <qcheckbox.h>
#include <qcombobox.h>
#include <qlabel.h>
#include <qlineedit.h>
#include <qlistbox.h>
#include <qpushbutton.h>
#include <qradiobutton.h>
#include <qspinbox.h>
#include <qtabwidget.h>
#include <qwidget.h>
#include <qlayout.h>
#include <qvariant.h>
#include <qtooltip.h>
#include <qwhatsthis.h>
#include <qimage.h>
#include <qpixmap.h>
#include <qbuttongroup.h>
#include <qpopupmenu.h>
#include <qarray.h>
#include <qinputdialog.h>
#include <qfont.h>
#include <qfontdialog.h> 

#include <qwt_plot.h>

pieDialog::pieDialog( QWidget* parent,  const char* name, bool modal, WFlags fl )
    : QDialog( parent, name, modal, fl )
{
    if ( !name )
	setName( "pieDialog" );
	setFixedWidth(521);
	setFixedHeight(260);
    setCaption( tr( "QtiPlot - Pie Options" ) );
    setSizeGripEnabled( FALSE );

    generalDialog = new QTabWidget( this, "generalDialog" );
	
	pieOptions = new QWidget( generalDialog, "pieOptions" );
	curvesList = new QListBox(pieOptions, "listBox" );
	
	GroupBox3 = new QButtonGroup(2,QGroupBox::Horizontal,tr( "Border" ),pieOptions, "GroupBox3" );

    new QLabel( tr( "Color" ), GroupBox3, "TextLabel4",0 );

    boxLineColor = new ColorBox( FALSE, GroupBox3);
	
	new QLabel(tr( "Style" ), GroupBox3, "TextLabel31",0 );  
    boxLineStyle = new QComboBox( FALSE, GroupBox3, "boxLineStyle" );
    boxLineStyle->insertItem("_____");
	boxLineStyle->insertItem("- - -");
	boxLineStyle->insertItem(".....");
	boxLineStyle->insertItem("_._._");
	boxLineStyle->insertItem("_.._..");
	
	new QLabel(tr( "Width" ), GroupBox3, "TextLabel3",0 );  
    boxLineWidth = new QSpinBox( GroupBox3, "boxLineWidth" );
	
	GroupBox2 = new QButtonGroup(2,QGroupBox::Horizontal,tr( "Fill" ),pieOptions, "GroupBox2" );

    new QLabel( tr( "First color" ), GroupBox2, "TextLabel4",0 ); 
    boxFirstColor = new ColorBox( FALSE, GroupBox2);
	
	new QLabel( tr( "Pattern" ), GroupBox2, "TextLabel41",0 );
	boxPattern = new PatternBox( FALSE, GroupBox2);
	
	new QLabel(tr( "Pie ray" ), GroupBox2, "rayLabel",0 );  
    boxRay= new QSpinBox(0,2000,10,GroupBox2, "boxRay");
	
	QHBoxLayout* hlayout1 = new QHBoxLayout(pieOptions,5,5, "hlayout1");
	hlayout1->addWidget(curvesList);
    hlayout1->addWidget(GroupBox3);
	hlayout1->addWidget(GroupBox2);
	
	generalDialog->insertTab(pieOptions, tr( "Pie" ) );
	
	frame = new QWidget( generalDialog, "frame" );
	GroupBox5 = new QButtonGroup(2,QGroupBox::Horizontal,tr(""),frame, "GroupBox5" );
	
	boxFramed = new QCheckBox(GroupBox5, "boxFramed" );
    boxFramed->setText( tr( "Draw canvas frame" ) );
	boxFramed->setChecked(TRUE);
	
	new QLabel(tr( "" ),GroupBox5, "TextLabel1_52",0 );
	
	new QLabel(tr( "Color" ),GroupBox5, "TextLabel1_53",0 );
	
	boxFrameColor= new ColorBox(GroupBox5);
	
	new QLabel(tr( "Width" ),GroupBox5, "TextLabel1_54",0 );
	boxFrameWidth= new QSpinBox(GroupBox5);
	boxFrameWidth->setMinValue(1);
	
	QVBoxLayout* hlayout4 = new QVBoxLayout(frame,5,5, "hlayout4");
    hlayout4->addWidget(GroupBox5);
	
	generalDialog->insertTab(frame, tr( "Frame" ) );
	
	GroupBox1 = new QButtonGroup(4,QGroupBox::Horizontal,tr(""),this, "GroupBox1" );
	GroupBox1->setLineWidth(0);
	GroupBox1->setFlat (TRUE);
	
	buttonWrk = new QPushButton( GroupBox1, "buttonWrk" );
    buttonWrk->setText( tr( "&Worksheet" ) );
	
	buttonApply = new QPushButton( GroupBox1, "buttonApply" );
    buttonApply->setText( tr( "&Apply" ) );
	
    buttonOk = new QPushButton(GroupBox1, "buttonOk" );
    buttonOk->setText( tr( "&OK" ) );
    buttonOk->setDefault( TRUE );
	
    buttonCancel = new QPushButton(GroupBox1, "buttonCancel" );
    buttonCancel->setText( tr( "&Cancel" ) );
	
	QVBoxLayout* vl = new QVBoxLayout(this,5,5, "vl");
	vl->addWidget(generalDialog);
    vl->addWidget(GroupBox1);
   
    // signals and slots connections
	connect( buttonWrk, SIGNAL(clicked()), this, SLOT(showWorksheet()));
	connect( buttonOk, SIGNAL( clicked() ), this, SLOT( accept() ) );
	connect( buttonCancel, SIGNAL( clicked() ), this, SLOT( reject() ) );
	connect( buttonApply, SIGNAL( clicked() ), this, SLOT(updatePlot() ) );
	connect(boxFramed,SIGNAL(toggled(bool)), this, SLOT(drawFrame(bool)));
	connect(curvesList, SIGNAL(rightButtonClicked(QListBoxItem *, const QPoint &)), this, SLOT(showPopupMenu(QListBoxItem *, const QPoint &)));
}

void pieDialog::showWorksheet()
{
emit worksheet(curvesList->currentText ());
close();
}

void pieDialog::showPopupMenu(QListBoxItem *, const QPoint &point)
{
QPopupMenu contextMenu(this);
contextMenu.insertItem("&Delete", this, SLOT(removeCurve()));
contextMenu.exec(point);
}

void pieDialog::removeCurve()
{
emit toggleCurve();
curvesList->removeItem (0);
}

void pieDialog::setPieSize(int size)
{
boxRay->setValue(size);
}

void pieDialog::setFramed(bool ok)
{
boxFramed->setChecked(ok);
}

void pieDialog::drawFrame(bool framed)
{
boxFrameWidth->setEnabled(framed);
boxFrameColor->setEnabled(framed);
	
emit drawFrame(framed,boxFrameWidth->text().toInt(),frameColor());
}

void pieDialog::setFrameWidth(int w)
{
boxFrameWidth->setValue(w);
}

void pieDialog::setFrameColor(const QColor& c)
{
  boxFrameColor->setColor(c);
}

void pieDialog::insertCurveName(const QString& name)
{
curvesList->clear();
curvesList->insertItem(name,-1);
curvesList->setCurrentItem (0);
}

void pieDialog::accept()
{
updatePlot();
close();
}

void pieDialog::updatePlot()
{
if (generalDialog->currentPage()==(QWidget *)pieOptions)
	{
	QPen pen=QPen(borderColor(),boxLineWidth->value(), style());
	emit updatePie(pen, pattern(), boxRay->value(), boxFirstColor->currentItem());	
	}
	
if (generalDialog->currentPage()==(QWidget *)frame)
	emit drawFrame(boxFramed->isChecked(),boxFrameWidth->value(),frameColor());
}

void pieDialog::setBorderWidth(int width)
{
boxLineWidth->setValue(width);
}

void pieDialog::setFirstColor(int c)
{
boxFirstColor->setCurrentItem(c);	
}

void pieDialog::setBorderColor(const QColor& c)
{
  boxLineColor->setColor(c);
}

QColor pieDialog::borderColor()
{
  return boxLineColor->getSelectedColor();
}

QColor pieDialog::frameColor()
{
  return boxFrameColor->getSelectedColor();
}

Qt::PenStyle pieDialog::style()
{
Qt::PenStyle style;
switch (boxLineStyle->currentItem())
	{
	case 0:
		style=Qt::SolidLine;
	break;
	case 1:
		style=Qt::DashLine;
	break;
	case 2:
		style=Qt::DotLine;
	break;
	case 3:
		style=Qt::DashDotLine;
	break;
	case 4:
		style=Qt::DashDotDotLine;
	break;
	}
return style;
}

void pieDialog::setBorderStyle(const Qt::PenStyle& style)
{
if(style == Qt::SolidLine)
	boxLineStyle->setCurrentItem(0);
if(style == Qt::DashLine)
	boxLineStyle->setCurrentItem(1);
if(style == Qt::DotLine)
	boxLineStyle->setCurrentItem(2);
if(style == Qt::DashDotLine)
	boxLineStyle->setCurrentItem(3);
if(style == Qt::DashDotDotLine)
	boxLineStyle->setCurrentItem(4);
}

void pieDialog::setPattern(const Qt::BrushStyle& style)
{
  boxPattern->setPattern(style);
}


Qt::BrushStyle pieDialog::pattern()
{
  return boxPattern->getSelectedPattern();
}

pieDialog::~pieDialog()
{
    // no need to delete child widgets, Qt does it all for us
}
